"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalNodeHandler = void 0;
const electron_1 = require("electron");
const EventBus_1 = require("../EventBus");
const types_1 = require("../types");
const LocalNodeProcess_1 = require("./process/LocalNodeProcess");
class LocalNodeHandler {
    constructor() {
        this.localNode = new LocalNodeProcess_1.LocalNodeProcess();
        electron_1.ipcMain.handle(types_1.CommunicationChannel.LOCALNODE, (event, typeOfRequest, netTypeId) => this.handleRequest(typeOfRequest, netTypeId));
    }
    /**
     * Starts local node process
     */
    start(netTypeId) {
        this.localNode.setNetypId(netTypeId);
        this.localNode.startLocalProcess();
    }
    /**
     * Terminates local node and removes handler
     */
    stop() {
        electron_1.ipcMain.removeHandler(types_1.CommunicationChannel.LOCALNODE);
        if (this.localNode.isRunning()) {
            this.localNode.killDaemon();
        }
        this.checkIfDaemonsQuit();
    }
    checkIfDaemonsQuit() {
        if (this.daemonsKilled()) {
            EventBus_1.appEventBus.emit(EventBus_1.LOCAL_NODE_STOPPED_EVENT);
            return;
        }
        this.addDaemonsQuitChecker();
    }
    handleRequest(typeOfRequest, netTypeId) {
        switch (typeOfRequest) {
            case "start":
                this.start(netTypeId);
                return true;
            case "stop":
                this.stop();
                return true;
            case "state":
                return this.getLocalNodeState();
        }
    }
    getLocalNodeState() {
        return this.localNode.getState();
    }
    /**
     * Checks if daemons have been killed
     */
    daemonsKilled() {
        return this.localNode.isRunning() === false;
    }
    /**
     * Validates daemon is killed and emits stop event
     */
    addDaemonsQuitChecker() {
        const i = setInterval(() => {
            if (this.daemonsKilled()) {
                clearInterval(i);
                EventBus_1.appEventBus.emit(EventBus_1.LOCAL_NODE_STOPPED_EVENT);
            }
        }, 500);
    }
}
exports.LocalNodeHandler = LocalNodeHandler;
