"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalNodeProcess = void 0;
const child_process_1 = require("child_process");
const electron_1 = require("electron");
const localNodeSettings_1 = require("../localNodeSettings");
const env_1 = require("../../env");
class LocalNodeProcess {
    constructor() {
        this._isRunning = false;
        this._shutDownRequested = false;
    }
    setNetypId(value) {
        this._netTypeId = value;
    }
    getNetypId() {
        return this._netTypeId;
    }
    getConfig() {
        return this.config;
    }
    setConfig(config) {
        this.config = config;
    }
    getState() {
        return {
            isRunning: this._isRunning,
        };
    }
    onstderrData(chunk) {
        if (env_1.isDevMode) {
            console.error("havend stderr : " + chunk.toString());
        }
    }
    onstdoutData(chunk) {
        if (env_1.isDevMode) {
            console.error("havend stdout : " + chunk.toString());
        }
    }
    killDaemon() {
        if (env_1.isDevMode) {
            console.log(`try to kill havend`);
        }
        this._shutDownRequested = true;
        this.daemonProcess.kill();
        // if deamon doesn't die, we kill it hard
        setTimeout(() => this._isRunning && this.killHard(), 10000);
    }
    isRunning() {
        return this._isRunning;
    }
    startLocalProcess() {
        const config = this.getConfig();
        this.filePath = (0, localNodeSettings_1.getLocalDaemonPath)(this._netTypeId);
        this.startArgs = config.args;
        this.port = config.port;
        const args = Object.entries(this.startArgs).map(([key, value]) => {
            return "--" + key + (value !== "" ? "=" + value : "");
        });
        if (env_1.isDevMode) {
            console.log(args);
            console.log(this.filePath);
        }
        this._isRunning = true;
        this.daemonProcess = (0, child_process_1.spawn)(this.filePath, args);
        this.daemonProcess.stdout.on("data", (chunk) => this.onstdoutData(chunk));
        this.daemonProcess.stderr.on("data", (chunk) => this.onstderrData(chunk));
        this.daemonProcess.on("exit", (code, signal) => this.onDaemonExit(code, signal));
        this.daemonProcess.on("error", (error) => this.onDaemonError(error));
    }
    onDaemonError(error) {
        if (env_1.isDevMode) {
            console.error("daemon error : " + error);
        }
    }
    onDaemonExit(code, signal) {
        this._isRunning = false;
        if (code !== 0 && code !== null) {
            electron_1.dialog.showErrorBox(`havend not running`, "Process was stopped or did not even start");
        }
        if (env_1.isDevMode) {
            console.log(`havend exit with code ${code} and signal ${signal}`);
        }
    }
    killHard() {
        this.daemonProcess.kill("SIGKILL");
    }
}
exports.LocalNodeProcess = LocalNodeProcess;
