"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enableKeysMenu = exports.createMenu = void 0;
const electron_1 = require("electron");
const env_1 = require("./env");
const keys_1 = require("./keys");
const electron_2 = require("electron");
const isMac = process.platform === "darwin";
const havenMenu = [
    // { role: 'appMenu' }
    ...(isMac
        ? [
            {
                label: electron_1.app.name,
                submenu: [
                    { role: "about" },
                    { type: "separator" },
                    { role: "hide" },
                    // @ts-ignore
                    ...(env_1.isDevMode ? [{ role: "forcereload" }] : []),
                    { role: "hideothers" },
                    { role: "unhide" },
                    { type: "separator" },
                    { role: "quit" },
                ],
            },
        ]
        : []),
    // { role: 'fileMenu' }
    {
        label: "File",
        submenu: [isMac ? { role: "close" } : { role: "quit" }],
    },
    {
        label: "Edit",
        submenu: [
            { role: "undo" },
            { role: "redo" },
            { type: "separator" },
            { role: "cut" },
            { role: "copy" },
            { role: "paste" },
            ...(isMac
                ? [
                    { role: "pasteAndMatchStyle" },
                    { role: "delete" },
                    { role: "selectAll" },
                    { type: "separator" },
                    {
                        label: "Speech",
                        submenu: [{ role: "startspeaking" }, { role: "stopspeaking" }],
                    },
                ]
                : [{ role: "delete" }, { type: "separator" }, { role: "selectAll" }]),
        ],
    },
    {
        label: "View",
        submenu: [
            { role: "resetzoom" },
            { role: "zoomin" },
            { role: "zoomout" },
            { type: "separator" },
            { role: "togglefullscreen" },
        ],
    },
    {
        label: "Social",
        submenu: [
            {
                label: "Twitter",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://twitter.com/havenxhv");
                },
            },
            {
                label: "Medium",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://havenprotocol.medium.com/");
                },
            },
            { type: "separator" },
            {
                label: "Discord",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://discordapp.com/invite/CCtNxfG");
                },
            },
            {
                label: "Reddit",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://www.reddit.com/r/havenprotocol/");
                },
            },
            {
                label: "Telegram",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://web.telegram.org/#/im?p=s1273047334_13986713956461503950");
                },
            },
            { type: "separator" },
            {
                label: "Github",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://github.com/haven-protocol-org");
                },
            },
        ],
    },
    {
        label: "Knowledge",
        submenu: [
            {
                label: "White Papers",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://havenprotocol.org/whitepaper/");
                },
            },
            {
                label: "Knowledge Base",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://havenprotocol.org/knowledge/");
                },
            },
        ],
    },
    {
        label: "Keys",
        id: "Keys",
        submenu: [
            {
                label: "Show Public Spend Key",
                click: () => (0, keys_1.showKey)(keys_1.KeyType.PUBLIC_SPEND),
            },
            {
                label: "Show Public View Key",
                click: () => (0, keys_1.showKey)(keys_1.KeyType.PUBLIC_VIEW),
            },
            {
                label: "Show Private View Key",
                click: () => (0, keys_1.showKey)(keys_1.KeyType.PRIVATE_VIEW),
            },
            {
                label: "Show Private Spend Key",
                click: () => (0, keys_1.showKey)(keys_1.KeyType.PRIVATE_SPEND),
            },
            {
                label: "Show Mnemonic Seed",
                click: () => (0, keys_1.showKey)(keys_1.KeyType.MNEMONIC),
            },
        ],
    },
    // { role: 'windowMenu' }
    {
        label: "Window",
        submenu: [
            { role: "minimize" },
            { role: "zoom" },
            ...(isMac
                ? [
                    { type: "separator" },
                    { role: "front" },
                    { type: "separator" },
                    { role: "window" },
                ]
                : [{ role: "close" }]),
        ],
    },
    {
        role: "help",
        submenu: [
            {
                label: "Discord Support Channel",
                click: async () => {
                    const { shell } = require("electron");
                    await shell.openExternal("https://discordapp.com/channels/536838513182638090/570818940553527296");
                },
            },
        ],
    },
];
const createMenu = () => {
    const menu = electron_2.Menu.buildFromTemplate(havenMenu);
    electron_2.Menu.setApplicationMenu(menu);
    (0, exports.enableKeysMenu)(false);
};
exports.createMenu = createMenu;
const enableKeysMenu = (enable) => {
    const menu = electron_2.Menu.getApplicationMenu();
    const menuItem = menu.getMenuItemById("Keys");
    menuItem.enabled = enable;
    electron_2.Menu.setApplicationMenu(menu);
};
exports.enableKeysMenu = enableKeysMenu;
