"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HavenWalletListener = void 0;
const haven_wallet_core_1 = require("haven-wallet-core");
const types_1 = require("../types");
class HavenWalletListener extends haven_wallet_core_1.MoneroWalletListener {
    constructor(webContent) {
        super();
        this.isSyncing = false;
        this.webContent = webContent;
    }
    onSyncProgress(height, startHeight, endHeight, percentDone, message) {
        if (percentDone === 1) {
            this.isSyncing = false;
        }
        else {
            this.isSyncing = true;
        }
        const syncDistance = endHeight - height;
        let updateInterval = Math.pow(10, Math.floor(Math.log10(syncDistance)));
        updateInterval = Math.min(1000, updateInterval);
        updateInterval = Math.max(updateInterval, 1);
        if (syncDistance % updateInterval === 0 || height === startHeight) {
            const walletupdate = {
                methodName: "onSyncProgress",
                params: [...arguments],
            };
            this.webContent.send(types_1.CommunicationChannel.WALLET, walletupdate);
        }
    }
    onNewBlock(height) {
        const walletupdate = {
            methodName: "onNewBlock",
            params: [...arguments],
        };
        if (!this.isSyncing) {
            this.webContent.send(types_1.CommunicationChannel.WALLET, walletupdate);
        }
    }
    // @ts-ignore
    onBalancesChanged(newBalance, newUnlockedBalance, assetType) {
        const walletupdate = {
            methodName: "onBalancesChanged",
            params: [...arguments],
        };
        this.webContent.send(types_1.CommunicationChannel.WALLET, walletupdate);
    }
    onOutputReceived(output) {
        // console.log("Hey you received some money");
    }
    onOutputSpent(output) {
        // console.log("Hey you sent some money");
    }
}
exports.HavenWalletListener = HavenWalletListener;
