"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WalletHandler = void 0;
const electron_1 = require("electron");
const core = __importStar(require("../shared/wallet"));
const daemon = __importStar(require("../shared/havend"));
const dev_1 = require("../dev");
const index_1 = require("../index");
const types_1 = require("../types");
const walletPaths_1 = require("./walletPaths");
const HavenWalletListener_1 = require("./HavenWalletListener");
const menu_1 = require("../menu");
/**
 * this class establishes the communication between client app and wallet
 */
class WalletHandler {
    constructor() {
        this.handleWalletCoreRequest = async (request) => {
            const methodName = request.methodName;
            const params = request.params;
            (0, dev_1.logInDevMode)(request.methodName);
            if (methodName === "addWalletListener") {
                this.addWalletListener();
                (0, menu_1.enableKeysMenu)(true);
                return;
            }
            if (methodName === "closeWallet") {
                (0, menu_1.enableKeysMenu)(false);
            }
            try {
                const response = await core[methodName].call(null, ...params);
                (0, dev_1.logInDevMode)(response);
                if (methodName === "getTxs") {
                    const txClassObjects = response;
                    const txJsonObjects = txClassObjects.map((tx) => {
                        const txJson = tx.toJson();
                        // little workaround to preserve block data ( height, timestamp ) in tx
                        if (tx.getBlock()) {
                            const block = tx.getBlock().toJson();
                            delete block.txs;
                            txJson.block = block;
                        }
                        return txJson;
                    });
                    return txJsonObjects;
                }
                if (methodName === "transfer" || methodName === "sweep") {
                    const txClassObjects = response;
                    const txJsonObjects = txClassObjects.map((tx) => {
                        // serialize tx data
                        return tx.toJson();
                    });
                    return txJsonObjects;
                }
                if (methodName === "getCollateralRequirements" || methodName === "getMaxDestinationAmount" || methodName === "getBlockCap") {
                    return response.toString();
                }
                if (methodName === "getSubAddresses") {
                    const addressClassObjects = response;
                    const addressJsonObjects = addressClassObjects.map((address) => {
                        // serialize address data
                        return address.toJson();
                    });
                    return addressJsonObjects;
                }
                if (methodName === "createSubAddress" || methodName === "getBalance" || methodName === "getUnlockedBalance" || methodName === "getCirculatingSupply") {
                    // serialize address and balance data
                    return response.toJson();
                }
                return response;
            }
            catch (e) {
                (0, dev_1.logInDevMode)(e);
                return {
                    message: e.message,
                    status: "error",
                    code: e.code
                };
            }
        };
        this.handleDaemonCoreRequest = async (request) => {
            const methodName = request.methodName;
            const params = request.params;
            try {
                const response = await daemon[methodName].call(null, ...params);
                if (response.toJson) {
                    const jsonResponse = response.toJson();
                    return jsonResponse;
                }
                return response;
            }
            catch (e) {
                return e.toString();
            }
        };
        this.addWalletListener = () => {
            const listener = new HavenWalletListener_1.HavenWalletListener(index_1.mainWindow.webContents);
            core.addWalletListener(listener);
        };
    }
    start() {
        this.addHandlers();
    }
    quit() {
        this.removeHandlers();
    }
    addHandlers() {
        electron_1.ipcMain.handle(types_1.CommunicationChannel.STORED_WALLETS, (event, netTypeID) => (0, walletPaths_1.getAvailableWallets)(netTypeID));
        electron_1.ipcMain.handle(types_1.CommunicationChannel.WALLET, (event, args) => this.handleWalletCoreRequest(args));
        electron_1.ipcMain.handle(types_1.CommunicationChannel.DAEMON, (event, args) => this.handleDaemonCoreRequest(args));
    }
    removeHandlers() {
        electron_1.ipcMain.removeHandler(types_1.CommunicationChannel.WALLET);
        electron_1.ipcMain.removeHandler(types_1.CommunicationChannel.DAEMON);
        electron_1.ipcMain.removeHandler(types_1.CommunicationChannel.STORED_WALLETS);
    }
}
exports.WalletHandler = WalletHandler;
